@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -178,6 +178,10 @@ public abstract class AbstractStep<O,I> implements Step<O,I>{
 
     // this opens the current page in the developers browser while debugging for a fast overview.
     protected void openPageInBrowser(Page page){
+        if (null == page) {
+            // Nothing to open
+            return;
+        }
         File file = new File ("./crawlerTestPage.html");
         Writer output = null;
         try {
